<?php

namespace Tygh\Addons\SwBifitOnline;

use Tygh\Addons\SwBifitOnline\Logs;
use Tygh\Addons\SwBifitOnline\Client;
use Tygh\Http;
use Exception;

/**
 * Bifit CheckContent
 */
class CheckContent
{
    protected $token;
    protected $addon;

    public function __construct($token, $addon_settings)
    {
        $this->token = $token;
        $this->addon = $addon_settings;
    }

    public function getCheckContent($order, $return = false)
    {
        $token_data = $this->token;
        $addon = $this->addon;

        $type = "SALE";
        if ($return == true) {
            $type = "SALE_RETURN";
        }

        $bifitkassa_payment_type = "CARD";
        if (!empty($order["payment_method"]["bifitkassa_payment_type"])) {
            $bifitkassa_payment_type =
                $order["payment_method"]["bifitkassa_payment_type"];
        }

        $address = "";
        if (!empty($order["phone"])) {
            $address = preg_replace("/[^,.0-9]/", "", $order["phone"]);
        } else {
            $address = $order["email"];
        }

        // check shipping_cost
        $shipping_cost = 0;
        if (isset($order["shipping_cost"]) && $order["shipping_cost"] > 0) {
            $shipping_cost = $order["shipping_cost"];
        }

        // check disqount
        $discount = 0;
        if (
            isset($order["subtotal_discount"]) &&
            $order["subtotal_discount"] > 0
        ) {
            // subtotal - total before disqount
            $discount = 100 - ($order["total"] * 100) / $order["subtotal"];
        }

        $products = [];
        if (!empty($order["products"])) {
            // changed by denben777
            /*$plus_price = 0;
			if ($shipping_cost > 0) {
				$count_products = count($order['products']);
				$plus_price = $shipping_cost/$count_products;
			}*/
            // end

            foreach ($order["products"] as $k => $product) {
                // changed by denben777
                //$product['display_subtotal'] += $plus_price;
                // end

                // Скидка по каждому товару
                if ($discount > 0) {
                    // added by denben777
                    $p_price = sprintf(
                        "%.2f",
                        $product["price"] -
                            $product["price"] * ($discount / 100)
                    );
                    // end
                    $price_total_float = sprintf(
                        "%.2f",
                        $product["display_subtotal"]
                    );
                    $total = sprintf(
                        "%.2f",
                        $price_total_float -
                            $price_total_float * ($discount / 100)
                    );
                } else {
                    // added by denben777
                    $p_price = $product["price"];
                    // end
                    $total = $product["display_subtotal"];
                }

                // added by denben777
                $product["price"] = $p_price;
                // end

                $products[] = [
                    "calculationMethod" => $addon["method"],
                    "paymentSubject" => $addon["subject"],
                    "name" => $product["product"],
                    "price" => sprintf("%.2f", $product["price"]),
                    "quantity" => sprintf("%.3f", $product["amount"]),
                    "vat" => $addon["vat"],
                    // 'totalVat' => 0,
                    "total" => $total,
                ];
            }

            if ($shipping_cost > 0 && count($products)) {
                $products[] = [
                    "calculationMethod" => $addon["method"],
                    "paymentSubject" => "SERVICE",
                    "name" => "Доставка",
                    "price" => sprintf("%.2f", $shipping_cost),
                    "quantity" => "1",
                    "vat" => $addon["vat"],
                    // 'totalVat' => 0,
                    "total" => $shipping_cost,
                ];
            }
        }

        $data = [
            "type" => $type,
            "taxSystem" => $addon["sno"],
            "cashier" => [
                "name" => isset($addon["name_cassir"])
                    ? $addon["name_cassir"]
                    : "Иванов И.И.",
                "inn" => $addon["inn"],
            ],
            "client" => [
                "name" => $order["firstname"] . " " . $order["lastname"],
                "address" => $address,
            ],
            "paymentAddress" => $addon["PaymentAddress"],
            "items" => $products,
            "total" => sprintf("%.2f", $order["total"]),
            "payments" => [
                $bifitkassa_payment_type => sprintf("%.2f", $order["total"]),
            ],
        ];

        return $data;
    }
}
